@@ -25,7 +25,9 @@ _PREDEFINED_STATEMENTS = [['Match',], ['Create',], ['Merge',], ['Delete',],
     ['OnMatchSet', 'ON MATCH SET'], ['CreateIndexOn', 'CREATE INDEX ON'],
     ['UsingIndex', 'USING INDEX'], ['DropIndexOn', 'DROP INDEX ON'],
     ['CreateConstraintOn', 'CREATE CONSTRAINT ON'], ['OnCreate', 'ON CREATE'],
-    ['DropConstraintOn', 'DROP CONSTRAINT ON'], ['WHEN'], ['THEN']]
+    ['DropConstraintOn', 'DROP CONSTRAINT ON'], ['WHEN'], ['THEN'], ['NOT'],
+    ['XOR'], ['NULL'], ['IS_NULL', 'IS NULL'], ['IS_NOT_NULL', 'IS NOT NULL'],
+    ['OR'], ['IS']]
 _PREDEFINED_FUNCTIONS = [['size',], ['reverse',], ['head',], ['tail',],
     ['last',], ['extract',], ['filter',], ['reduce',], ['Type', 'type',],
     ['startNode',], ['endNode',], ['count',], ['collect',],
@@ -46,10 +48,11 @@ RELATIONSHIP_DIRECTIONS = {
 }
 
 
-def create_function(name, attrs=None):
+def create_function(name, attrs=None, func_raw=False):
     attrs = attrs or {}
+    func = Func if not func_raw else FuncRaw
 
-    setattr(_MODULE, name, type(name, (Func,), attrs))
+    setattr(_MODULE, name, type(name, (func,), attrs))
 
 
 def create_statement(name, attrs=None):
@@ -210,6 +213,10 @@ class Pypher(with_metaclass(_Link)):
         return self.add_link(link)
 
     def __call__(self, *args, **kwargs):
+        if ('name' not in kwargs and '_name' in self._bottom.__dict__
+            and type(self._bottom) is Statement):
+            kwargs['name'] = self._bottom.name
+
         func = self._bottom.__class__(*args, **kwargs)
 
         return self.remove_link(self._bottom).add_link(func)
@@ -709,7 +716,9 @@ class Map(_BaseLink):
         for arg in self.args:
             body.append(prep_value(arg))
 
-        for k, val in self.kwargs.items():
+        kwargs = OrderedDict(sorted(self.kwargs.items()))
+
+        for k, val in kwargs.items():
             pair = '`{}`: {}'.format(k, prep_value(val, k))
             body.append(pair)
 
@@ -976,4 +985,9 @@ for fun in _PREDEFINED_FUNCTIONS:
     except Exception as e:
         attrs = {'name': name}
 
-    create_function(name=name, attrs=attrs)
+    try:
+        func_raw = bool(fun[2])
+    except Exception as e:
+        func_raw = False
+
+    create_function(name=name, attrs=attrs, func_raw=func_raw)
