@@ -1,4 +1,4 @@
-from random import randrange, random
+from random import randrange, random, randint
 
 import unittest
 import re
@@ -37,6 +37,27 @@ class BuilderTests(unittest.TestCase):
 
         self.assertEqual(str(p), ' '.join(expected))
 
+    def test_pypher_can_create_dynamic_statment(self):
+        p = Pypher()
+        p.my_statement(1, 2, 3)
+
+        exp = 'my_statement 1, 2, 3'
+        q = str(p)
+
+        self.assertEqual(exp, q)
+        self.assertEqual(0, len(p.bound_params))
+
+    def test_pypher_can_create_dynamic_statment_random(self):
+        p = Pypher()
+        stmt = 'my_statment_{}'.format(randint(1, 777))
+        getattr(p, stmt)(1, 2, 3)
+
+        exp = '{} 1, 2, 3'.format(stmt)
+        q = str(p)
+
+        self.assertEqual(exp, q)
+        self.assertEqual(0, len(p.bound_params))
+
     def test_pypher_created_functions(self):
         p = Pypher()
         expected = []
@@ -497,7 +518,7 @@ class BuilderTests(unittest.TestCase):
         p.RETURN.map(one, two, three=three, list=[four, five])
         q = str(p)
         params = p.bound_params
-        exp = 'RETURN {{one, two, `three`: ${three}, `list`: [${four}, ${five}]}}'.format(
+        exp = 'RETURN {{one, two, `list`: [${four}, ${five}], `three`: ${three}}}'.format(
             three=get_dict_key(params, three),
             four=get_dict_key(params, four),
             five=get_dict_key(params, five))
@@ -516,7 +537,7 @@ class BuilderTests(unittest.TestCase):
         p.RETURN.mapprojection(user, one, two, three=three, list=[four, five])
         q = str(p)
         params = p.bound_params
-        exp = 'RETURN user {{one, two, `three`: ${three}, `list`: [${four}, ${five}]}}'.format(
+        exp = 'RETURN user {{one, two, `list`: [${four}, ${five}], `three`: ${three}}}'.format(
             three=get_dict_key(params, three),
             four=get_dict_key(params, four),
             five=get_dict_key(params, five))
@@ -857,7 +878,7 @@ class OperatorTests(unittest.TestCase):
         p.SET.user += d
         q = str(p)
         params = p.bound_params
-        exp = 'SET user += {{`name`: ${name}, `age`: ${age}}}'.format(
+        exp = 'SET user += {{`age`: ${age}, `name`: ${name}}}'.format(
             name=get_dict_key(params, d['name']),
             age=get_dict_key(params, d['age']))
 
@@ -901,7 +922,7 @@ class OperatorTests(unittest.TestCase):
         p.SET.user += d
         q = str(p)
         params = p.bound_params
-        exp = ('SET user += {{`name`: ${name}, `loc`: {{`city`: ${city}, `latlng`: [${lat}, ${lng}]}}}}').format(
+        exp = ('SET user += {{`loc`: {{`city`: ${city}, `latlng`: [${lat}, ${lng}]}}, `name`: ${name}}}').format(
             name=get_dict_key(params, d['name']),
             city=get_dict_key(params, d['loc']['city']),
             lat=get_dict_key(params, lat),
